; Peripheral base addresses
DMA		EQU	0x40008100	; DMA controller	
GPIO		EQU	0x4000F000  	; GPIO controller (aliased to 0x400F_F000)
Flash		EQU	0x40020000  	; Flash memory
DMAMUX		EQU	0x40021000	; DMA channel mutiplexer 
PIT		EQU	0x40037000 	; Periodic interrupt timers	
TPM0		EQU	0x40038000 	; Timer/PWM (TPM) 0
TPM1		EQU	0x40039000 	; Timer/PWM (TPM) 1
ADC0		EQU	0x4003B000	; Analog-to-digital converter (ADC) 0
RTC		EQU	0x4003D000 	; Real-time clock (RTC)	
DAC0		EQU	0x4003F000	; Digital-to-analog converter (DAC) 0 	
LPTMR0		EQU	0x40040000 	; Low-power timer (LPTMR)
TSI		EQU	0x40045000  	; Touch sense interface (TSI)	
SIML		EQU	0x40047000 	; SIM low-power logic
SIM		EQU	0x40048000 	; System integration module (SIM)
PORTA		EQU	0x40049000 	; Port A multiplexing control
PORTB		EQU	0x4004A000 	; Port B multiplexing control
MCG		EQU	0x40064000 	; Multi-purpose Clock Generator (MCG)
OSC		EQU	0x40065000 	; System oscillator (OSC)
I2C0		EQU	0x40066000 	; I2C 0
UART0		EQU	0x4006A000 	; UART 0
COMP		EQU	0x40073000 	; Analog comparator (CMP) / 6-bit DAC
SPI0		EQU	0x40076000 	; SPI 0
LLWU		EQU	0x4007C000  	; Low-leakage wakeup unit (LLWU)	
PMC		EQU	0x4007D000 	; Power management controller (PMC)
SMC		EQU	0x4007E000 	; System Mode controller (SMC)
RCM		EQU	0x4007F000 	; Reset Control Module (RCM)
GPIOA		EQU	0x400FF000	; GPIOA controller
GPIOB		EQU	0x400FF040	; GPIOB controller

;----------- DMA registers --------------------------------------------------------
DMA0_SAR	EQU	0x00		; Source Address Register
DMA0_DAR	EQU	0x04 		; Destination Address Register
DMA0_DSR_BCR	EQU	0x08 		; DMA Status Register / Byte Count Register
DMA0_DCR	EQU	0x0C		; DMA Control Register
DMA1_SAR	EQU	0x10		; Source Address Register
DMA1_DAR	EQU	0x14 		; Destination Address Register
DMA1_DSR_BCR	EQU	0x18 		; DMA Status Register / Byte Count Register
DMA1_DCR	EQU	0x1C		; DMA Control Register
DMA2_SAR	EQU	0x20		; Source Address Register
DMA2_DAR	EQU	0x24 		; Destination Address Register
DMA2_DSR_BCR	EQU	0x28 		; DMA Status Register / Byte Count Register
DMA2_DCR	EQU	0x2C		; DMA Control Register
DMA3_SAR	EQU	0x30		; Source Address Register
DMA3_DAR	EQU	0x34 		; Destination Address Register
DMA3_DSR_BCR	EQU	0x38 		; DMA Status Register / Byte Count Register
DMA3_DCR	EQU	0x3C		; DMA Control Register

;----------- DMAMUX registers -----------------------------------------------------
DMAMUX_CHCFG0	EQU	0x00		; Channel 0 Configuration register
DMAMUX_CHCFG1	EQU	0x01 		; Channel 1 Configuration register
DMAMUX_CHCFG2	EQU	0x02 		; Channel 2 Configuration register 
DMAMUX_CHCFG3	EQU	0x03		; Channel 3 Configuration register

;----------- ADC registers ------------------------------------------------------
ADC_SC1A	EQU	0x00		; ADC Status and Control Registers 1
ADC_SC1B	EQU	0x04 		; ADC Status and Control Registers 1 
ADC_CFG1 	EQU	0x08 		; ADC Configuration Register 1
ADC_CFG2 	EQU	0x0C 		; ADC Configuration Register 2 
ADC_RA		EQU	0x10 		; ADC Data Result Register 
ADC_RB		EQU	0x14 		; ADC Data Result Register 
ADC_CV1		EQU	0x18 		; Compare Value Registers 
ADC_CV2		EQU	0x1C 		; Compare Value Registers 
ADC_SC2		EQU	0x20 		; Status and Control Register 2 
ADC_SC3		EQU	0x24 		; Status and Control Register 3 
ADC_OFS		EQU	0x28 		; ADC Offset Correction Register 
ADC_PG		EQU	0x2C 		; ADC Plus-Side Gain Register 
ADC_CLPD	EQU	0x34 		; ADC Plus-Side General Calibration Value Register 
ADC_CLPS	EQU	0x38 		; ADC Plus-Side General Calibration Value Register 
ADC_CLP4	EQU	0x3C 		; ADC Plus-Side General Calibration Value Register
ADC_CLP3	EQU	0x40 		; ADC Plus-Side General Calibration Value Register
ADC_CLP1	EQU	0x48 		; ADC Plus-Side General Calibration Value Register
ADC_CLP0	EQU	0x4C 		; ADC Plus-Side General Calibration Value Register

;----------- DAC registers ------------------------------------------------------
DAC_DAT0L	EQU	0x00		; DAC Data Low Register
DAC_DAT0H	EQU	0x01		; DAC Data High Register
DAC_DAT1L	EQU	0x02		; DAC Data Low Register
DAC_DAT1H	EQU	0x03		; DAC Data High Register
DAC_SR		EQU	0x20		; DAC Status Register
DAC_C0		EQU	0x21		; DAC Control Register 0
DAC_C1		EQU	0x22		; DAC Control Register 1	
DAC_C2		EQU	0x23		; DAC Control Register 2

;----------- LPTMR registers ----------------------------------------------------
LPTMR_CSR	EQU	0x00		; Low Power Timer Control Status Register
LPTMR_PSR	EQU	0x04		; Low Power Timer Prescale Register
LPTMR_CMR	EQU	0x08		; Low Power Timer Compare Register
LPTMR_CNR	EQU	0x0C		; Low Power Timer Counter Register

;----------- SIM registers -----------------------------------------------------
SIM_SOPT2	EQU	0x04 		; System Options Register 2 
SIM_SOPT4	EQU	0x0C 		; System Options Register 4 
SIM_SOPT5	EQU	0x10 		; System Options Register 5 
SIM_SOPT7	EQU	0x18 		; System Options Register 7 
SIM_SCGC4	EQU	0x34		; System Clock Gating Control Register 4
SIM_SCGC5	EQU	0x38		; System Clock Gating Control Register 5
SIM_SCGC6	EQU	0x3C		; System Clock Gating Control Register 6
SIM_SCGC7	EQU	0x40 		; System Clock Gating Control Register 7 
SIM_CLKDIV1	EQU	0x44		; System Clock Divider Register 1
SIM_COPC	EQU	0x100		; COP Control Register

;----------- PORT registers ------------------------------------------------------
PORT_PCR0	EQU	0x00		; Pin Control Register n
PORT_GPCLR	EQU	0x80		; Global Pin Control Low Register
PORT_GPCHR	EQU	0x84		; Global Pin Control High Register
PORT_ISFR	EQU	0xA0 		; Interrupt Status Flag Register
	
;----------- MCG registers -----------------------------------------------------
MCG_C1		EQU	0x00		; MCG Control 1 Register
MCG_C2		EQU	0x01		; MCG Control 2 Register
MCG_C3		EQU	0x02		; MCG Control 3 Register
MCG_C4		EQU	0x03		; MCG Control 4 Register
MCG_C6		EQU	0x05		; MCG Control 6 Register
MCG_S		EQU	0x06		; MCG Status Register
MCG_SC		EQU	0x08		; MCG Status and Control Register

;----------- I2C registers -----------------------------------------------------
I2C_A1		EQU	0x00		; I2C Address Register 1
I2C_F		EQU	0x01		; I2C Frequency Divider register
I2C_C1		EQU	0x02		; I2C Control Register 1
I2C_S		EQU	0x03		; I2C Status register
I2C_D		EQU	0x04		; I2C Data I/O register
I2C_C2		EQU	0x05		; I2C Control Register 2
I2C_FLT		EQU	0x06		; I2C Programmable Input Glitch Filter register
I2C_RA		EQU	0x07		; I2C Range Address register
I2C_SMB		EQU	0x08		; I2C SMBus Control and Status register
I2C_A2		EQU	0x09		; I2C Address Register 2
I2C_SLTH	EQU	0x0A		; I2C SCL Low Timeout Register High
I2C_SLTL	EQU	0x0B		; I2C SCL Low Timeout Register Low 

;----------- UART registers ----------------------------------------------------
UART_BDH	EQU	0x00		; UART Baud Rate Register High 
UART_BDL	EQU	0x01		; UART Baud Rate Register Low 
UART_C1		EQU	0x02		; UART Control Register 1 
UART_C2		EQU	0x03		; UART Control Register 2
UART_S1		EQU	0x04		; UART Status Register 1
UART_S2		EQU	0x05		; UART Status Register 2
UART_C3		EQU	0x06		; UART Control Register 3
UART_D		EQU	0x07		; UART Data Register
UART_MA1	EQU	0x08		; UART Match Address Registers 1 
UART_MA2	EQU	0x09		; UART Match Address Registers 2 
UART_C4		EQU	0x0A		; UART Control Register 4 
UART_C5		EQU	0x0B		; UART Control Register 5 
	
;----------- SPI registers -----------------------------------------------------
SPI_C1		EQU	0x00		; SPI Control Register 1 
SPI_C2		EQU	0x01 		; SPI Control Register 2 
SPI_BR		EQU	0x02 		; SPI Baud Rate Register
SPI_S		EQU	0x03 		; SPI Status Register 
SPI_D		EQU	0x05 		; SPI Data Register
SPI_M		EQU	0x07 		; SPI Match Register
	
;----------- SMC registers -----------------------------------------------------
SMC_PMPROT	EQU	0x00		; Power Mode Protection register
SMC_PMCTRL	EQU	0x01		; Power Mode Control register
SMC_STOPCTRL	EQU	0x02		; Stop Control Register
SMC_PMSTAT	EQU	0x03		; Power Mode Status register

;----------- GPIO registers -----------------------------------------------------
GPIO_PDOR	EQU	0x00		; Port Data Output Register
GPIO_PSOR	EQU	0x04		; Port Set Output Register
GPIO_PCOR	EQU	0x08		; Port Clear Output Register
GPIO_PTOR	EQU	0x0C		; Port Toggle Output Register
GPIO_PDIR	EQU	0x10		; Port Data Input Register
GPIO_PDDR	EQU	0x14		; Port Data Direction Register

;-------- ARM Core registers -----------------------------------------------------------------
NVIC_ISER	EQU	0xE000E100	; NVIC SETENA
NVIC_ICER	EQU	0xE000E180	; NVIC CLRENA
NVIC_ISPR	EQU	0xE000E200	; NVIC SETPEND
NVIC_ICPR	EQU	0xE000E280	; NVIC CLRPEND

SCB_SCR		EQU	0xE000ED10	; System Control Register
SLEEPDEEP	EQU	0x04		; bits in System Control Register
SLEEPONEXIT	EQU	0x02	

	MACRO				; store data in a given register
	PUTW	$wdata, $reg, $base
	IF	"$base" <> "" 
	ldr	R0, =$base
	ENDIF
	IF	$wdata <= 0xFF
	movs	R1, #$wdata
	ELSE
	ldr	R1, =$wdata
	ENDIF
	IF	$reg <= 0x7C
	str	R1, [R0, #$reg]
	ELIF	$reg <= 0xFF
	movs	R2, #$reg
	str	R1, [R0, R2]
	ELSE
	ldr	R2, =$reg	
	str	R1, [R0, R2]
	ENDIF			
	MEND

	MACRO
	PUTB	$wdata, $reg, $base
	IF	"$base" <> "" 
	ldr	R0, =$base
	ENDIF		
	movs	R1, #$wdata	
	IF	$reg <= 0x1F
	strb	R1, [R0, #$reg]
	ELIF	$reg <= 0xFF
	movs	R2, #$reg
	strb	R1, [R0, R2]
	ELSE
	ldr	R2, =$reg	
	strb	R1, [R0, R2]
	ENDIF		
	MEND

	MACRO
	GETW	$reg, $base
	IF	"$base" <> "" 
	ldr	R0, =$base
	ENDIF			
	IF	$reg <= 0x1F
	ldr	R1, [R0, #$reg]
	ELIF	$reg <= 0xFF
	movs	R1, #$reg
	ldr	R1, [R0, R1]
	ELSE
	ldr	R1, =$reg	
	ldr	R1, [R0, R1]
	ENDIF		
	MEND
	
	MACRO
	ORRB	$wdata, $reg, $base
	IF	"$base" <> "" 
	ldr	R0, =$base
	ENDIF		
	movs	R3, #$wdata	
	IF	$reg <= 0x1F
	ldrb	R1, [R0, #$reg]
	orrs	R1, R3
	strb	R1, [R0, #$reg]
	ELIF	$reg <= 0xFF
	movs	R2, #$reg
	ldrb	R1, [R0, R2]
	orrs	R1, R3
	strb	R1, [R0, R2]	
	ELSE
	ldr	R2, =$reg	
	ldrb	R1, [R0, R2]
	orrs	R1, R3
	strb	R1, [R0, R2]	
	ENDIF		
	MEND

	MACRO				; AND a word with data in memory
	IOANDW	$wdata, $addr
	ldr	R0, =($addr + (1<<26))
	ldr	R1, =$wdata
	str	R1, [R0]
	MEND

	MACRO				; AND a halfword with data in memory
	IOANDH	$wdata, $addr
	ldr	R0, =($addr + (1<<26))
	ldr	R1, =$wdata
	strh	R1, [R0]
	MEND

	MACRO				; AND a byte with data in memory
	IOANDB	$wdata, $addr
	ldr	R0, =($addr + (1<<26))
	movs	R1, #$wdata
	strb	R1, [R0]
	MEND
	
	MACRO				; OR a word with data in memory
	IOORW	$wdata, $addr
	ldr	R0, =($addr + (1<<27))
	ldr	R1, =$wdata
	str	R1, [R0]
	MEND

	MACRO				; OR a halfword with data in memory
	IOORH	$wdata, $addr 
	ldr	R0, =($addr + (1<<27))
	ldr	R1, =$wdata
	strh	R1, [R0]
	MEND

	MACRO				; OR a byte with data in memory
	IOORB	$wdata, $addr
	ldr	R0, =($addr + (1<<27))
	movs	R1, #$wdata
	strb	R1, [R0]
	MEND	
	
	MACRO				; XOR a word with data in memory
	IOXORW	$wdata, $addr
	ldr	R0, =($addr + (3<<26))
	ldr	R1, =$wdata
	str	R1, [R0]
	MEND

	MACRO				; XOR a halfword with data in memory
	IOXORH	$wdata, $addr
	ldr	R0, =($addr + (3<<26))
	ldr	R1, =$wdata
	strh	R1, [R0]
	MEND

	MACRO				; XOR a byte with data in memory
	IOXORB	$wdata, $addr
	ldr	R0, =($addr + (3<<26))
	movs	R1, #$wdata
	strb	R1, [R0]
	MEND		
		
	END
	