#include "hardware.h"
#include <MKL05Z4.h> 
#include <core_cm0plus.h>

void MCG_setup(void)							// configure system clock
{
	SIM->CLKDIV1 = SIM_CLKDIV1_OUTDIV4(4);			// set 1:5 bus clock divider
}

void SMC_setup(void)							// configure low-power run/stop modes
{
	SMC->PMPROT = SMC_PMPROT_AVLP_MASK;				// allow VLPR, VLPW, VLPS modes
	SMC->PMCTRL = SMC_PMCTRL_RUNM(2) | SMC_PMCTRL_STOPM(2); // enter VLPS mode in STOP 
}

void PORTS_setup(void)							// configure I/O ports
{
	SIM->SCGC5 |= SIM_SCGC5_PORTA_MASK | SIM_SCGC5_PORTB_MASK;	   // enable clock for I/O ports
	PORTA->GPCLR = PORT_GPCLR_GPWE(0x320) | PORT_GPCLR_GPWD(0x100); // configure PORTA[3:5,8:9] for GPIO
	PORTA->GPCLR = PORT_GPCLR_GPWE(0x18) | PORT_GPCLR_GPWD(0x103); // pull-up on those pins
	PORTB->GPCLR = PORT_GPCLR_GPWE(0xFF) | PORT_GPCLR_GPWD(0x103); // configure PORTB[1:7] for GPIO
	PTA->PDDR = 0x320;						// configure CS pin for output
	PTA->PDOR = 0x20;							// put CS high
	PTB->PDOR = 0;
	PTB->PDDR = 0xF9;							// configure PB[1:2] for input
	PORTB->PCR[6] = PORT_PCR_MUX(2);				// configure PB.6 for TPM0.3
	PORTB->PCR[7] = PORT_PCR_MUX(2); 				// configure PB.7 for TPM0.2
	NVIC_ClearPendingIRQ(PORTB_IRQn);
	NVIC_EnableIRQ(PORTB_IRQn);					// enable PB interrupt
}

void SPI0_setup(void)
{
	PORTA->GPCLR = PORT_GPCLR_GPWE(0xC0) | PORT_GPCLR_GPWD(0x300); // configure PORTA[6:7] for SPI0
	PORTB->GPCLR = PORT_GPCLR_GPWE(0x01) | PORT_GPCLR_GPWD(0x300); // configure PORTB[0] for SPI0
	SIM->SCGC4 |= SIM_SCGC4_SPI0_MASK;				// enable clock for SPI0 module
	SPI0->BR = 0;							// set bus_freq/2 baud rate	
	NVIC_ClearPendingIRQ(SPI0_IRQn);				// enable SPI0 interrupt in NVIC
	NVIC_EnableIRQ(SPI0_IRQn);
}

void TPM_setup(void)							// configure TPM for PWD
{
	SIM->SCGC6 |= SIM_SCGC6_TPM0_MASK;				// enable clock to TMP0
	SIM->SOPT2 |= SIM_SOPT2_TPMSRC(3);				// select MCGIRCLK clock
	TPM0->CONTROLS[2].CnSC = TPM_CnSC_MSB_MASK | TPM_CnSC_ELSB_MASK; // edge-aligned PWM mode
	TPM0->CONTROLS[2].CnV = 2048;					// set 50% duty cycle
	TPM0->CONTROLS[3].CnSC = TPM_CnSC_MSB_MASK | TPM_CnSC_ELSB_MASK; // edge-aligned PWM mode
	TPM0->CONTROLS[3].CnV = 2048;					// set 50% duty cycle
	TPM0->MOD = 4095;							// set module (12-bit PWM resolution)
}	
