	INCLUDE MKL05.inc			; CPU register definitions	
	PRESERVE8
	THUMB					; use thumb instruction set

CS	EQU	1<<5				; CS  = PA.5
	
	AREA	RAM, DATA, NOINIT, READWRITE, ALIGN=3
SPIbuf	SPACE	32			; SPI buffer
	EXPORT	SPIbuf	

;-------------------------------------------------------------------
	AREA    |.text|, CODE, READONLY	
SPIWriteBuf	PROC				; R0=buf, R1=len_TX, R2=len_RX
	EXPORT	SPIWriteBuf
	push	{LR,R4,R7,R0,R1,R2}	
wr	bl	CS_down
	ldr	R7, =SPIbuf
	movs	R2, #0x44
	strb	R2, [R7]
	movs	R3, #1			; send 0x44
	movs	R4, #1			; read 1 byte
	bl	SPI_transfer		; send READ_CMD_BUFF command
	bl	CS_up
	ldr	R7, =SPIbuf
	ldrb	R2, [R7]
	cmp	R2, #0xFF			; is CTS set?
	bne	wr

	bl	CS_down			; now send the command
	pop	{R0,R1,R2}
	mov	R7, R0			; source buffer
	mov	R3, R1			; # bytes to TX
	mov	R4, R2			; # bytes to RX
	bl	SPI_transfer
	bl	CS_up
	pop	{PC,R4,R7}
	ENDP

;-------------------------------------------------------------------
SPIReadStream	PROC			; R0=length
	EXPORT	SPIReadStream
	push	{LR,R4,R7,R0,R1,R2}	
	bl	CS_down
	ldr	R7, =SPIbuf
	movs	R2, #0x44
	strb	R2, [R7]
	movs	R3, #1			; send 0x44
	movs	R4, R0			; read that many bytes
	adds	R4, #1
	bl	SPI_transfer		; send READ_CMD_BUFF command
	bl	CS_up
	pop	{PC,R4,R7,R0,R1,R2}
	ENDP

;-------------------------------------------------------------------
SPIWriteBuf2 PROC				; R0=buf, R1=len_TX, R2=len_RX
	EXPORT	SPIWriteBuf2
	push	{LR,R7,R3,R4}	
	bl	CS_down			; now send the command
	mov	R7, R0			; source buffer
	mov	R3, R1			; # bytes to TX
	mov	R4, R2			; # bytes to RX
	bl	SPI_transfer
	bl	CS_up
	pop	{PC,R7,R3,R4}
	ENDP		

;-------------------------------------------------------------------
SPI0_IRQHandler	PROC
	EXPORT	SPI0_IRQHandler
	ldrb	R1, [R0, #SPI_S]
	cmp	R3, #0 			; all bytes transmitted?
	bmi	spi3			; RX operation
	beq	spi1			; switch to RX
	ldrb	R1, [R7]		; R1 = next byte to transmit
	strb	R1, [R0, #SPI_D]	; load it to TX buffer
	adds	R7, #1			; update buffer pointer
	subs	R3, #1			; all bytes sent?
	beq	spi0			; YES - wait for transfer end
	bx	LR			; NO  - send more bytes
	
spi0	ldrb	R1, [R0, #SPI_D]	; clear RX flag (R3 = 0)
	PUTB	0xD0, SPI_C1		; enable RX interrupt
	movs	R2, #2
	bx	LR			
	
spi1	ldrb	R1, [R0, #SPI_D]	; wait for the end of TX
	subs	R2, #1
	beq	spi2
	bx	LR
	
spi2	cmp	R4, #0			; receive bytes?
	beq	spi4			; NO  - exit
	ldrb	R1, [R0, #SPI_D]	; YES - clear RX flag (R3 = 0)
	strb	R4, [R0, #SPI_D]	; and request the first byte	
	subs	R3, #1			; R3 becomes <0 now
	ldr	R7, =SPIbuf		; save receiver bytes there
	bx	LR

spi3	ldrb	R1, [R0, #SPI_D]	; RX mode: get byte from RX buffer
	strb	R1, [R7]		; load byte to SPI buffer
	adds	R7, #1			; update buffer pointer	
	subs	R4, #1			; all bytes received?
	beq	spi4			; YES - exit
	strb	R4, [R0, #SPI_D]	; NO  - request the next byte
	bx	LR			
	
spi4	ldr	R3, =SCB_SCR		; cancel sleep on exit 
	movs	R1, #0
	str	R1, [R3]
	PUTB	0x50, SPI_C1		; disable SPI interrupts	
	bx	LR
	ENDP

;--------------------------------------------------------------------
SPI_transfer	PROC			; send data from SPIbuf
	EXPORT	SPI_transfer
	PUTW	SLEEPONEXIT, 0, SCB_SCR ; set sleep on exit
	PUTB	0x50, SPI_C1, SPI0	; enable SPI module TX, and interrupt
	nop
	PUTB	0x70, SPI_C1		; enable SPI TX empty interrupt	
	wfi	
	nop
	PUTB	0, SPI_C1			; SPI reset
	bx	LR
	ENDP

;---------------------------------------------------------------------
CS_down		PROC
	EXPORT	CS_down
	push	{LR,R0,R1,R2}	
	PUTW	0x00C00300, PORT_GPCLR, PORTA	; connect pins to SPI 
	PUTW	0x00010300, PORT_GPCLR, PORTB		
	ldr	R2, =GPIOA
	movs	R1, #CS
	str	R1, [R2, #GPIO_PCOR]	; CS down
	pop	{PC,R0,R1,R2}
	ENDP
		
CS_up			PROC
	EXPORT	CS_up
	push	{LR,R0,R1,R2}		
	ldr	R2, =GPIOA
	movs	R1, #CS
	str	R1, [R2, #GPIO_PSOR]	; CS up
	PUTW	0x00C00100, PORT_GPCLR, PORTA	; disconnect pins from SPI 
	PUTW	0x00010100, PORT_GPCLR, PORTB	
	pop	{PC,R0,R1,R2}
	ENDP
		
	ALIGN	
	END
