#include <MKL05Z4.h>
#include "hardware.h"
#include "radio.h"

#define FORWARD 	1						// radio commands
#define LEFT 	2
#define BACKWARDS 3
#define RIGHT 	4 
#define STOP	5

uint8_t command;
extern uint8_t SPIbuf[];

int main(void)
{  
	MCG_setup();						// configure clock for VLPR mode
	SMC_setup();						// configure low-power modes
	PORTS_setup();						// I/O ports setup	
	SPI0_setup();						// configure SPI0 module
	Radio_setup();						// configure radio-module
	TPM_setup();						// configure teimer for PWM mode
	
	while(1)							// main application loop
	{
		Clear_radioIF();					// clear radio interrupt flags
		PORTB->PCR[2] = PORT_PCR_MUX(1) | PORT_PCR_PE_MASK | PORT_PCR_PS_MASK |
		  PORT_PCR_ISF_MASK | PORT_PCR_IRQC(10);	// enable radio interrupt at PB2 		
		__WFI();						// wait for pin wake-up event
		
		Read_radio(); 					// read RX FIFO
		if (SPIbuf[0] != 3) 
			continue;					// check the received packet length
		if((SPIbuf[1] != 0xAA) || (SPIbuf[2] != 0xBB)) 
			continue;					// check TX and RX ids
		
		command = SPIbuf[3]; // execute the command (the direction the trackbot will go: up, down, left and right)
		switch(command)
		{
			case 1:					// 1 = forward
				TPM0->SC = TPM_SC_CMOD(1); 	// 1 = start pwm --> 0 = stop/clear pwm  
				PTA->PCOR = 0x300; 		// Ain2 and Bin2 needs to be low logic = 0
			break;

			case 2:					// 2 = left
				TPM0->SC = TPM_SC_CMOD(1);	// 1 = start pwm --> Sets Motor A and B in1 to start pwm
				PTA->PSOR = 0x100; 		// Ain2 high logic = 1
				PTA->PCOR = 0x200;		// Bin2 low logic = 0
			break;
				
			case 3:					// 3 = back
				TPM0->SC = TPM_SC_CMOD(1);	// 1 = start pwm --> Sets Motor A and B in1 to start pwm
				PTA->PSOR = 0x300; 		// Ain2 and Bin2 high logic or 1
				break;
				
			case 4:					// case 4 = right
				TPM0->SC = TPM_SC_CMOD(1);	// 1 = start pwm --> Sets Ain1 and Bin1 to start pwm
				PTA->PCOR = 0x100; 		// Ain2 high logic = 0
				PTA->PSOR = 0x200;		// Bin2 low logic = 1
			break;		
				
			case 5:					// 5 == stop need to stop pwm
				TPM0->SC = TPM_SC_CMOD(0);	//0 = stop/clear pwm --> Sets Motor A and B in1 to start pwm
				PTA->PCOR = 0x300; 		// clear pta9 and pta8
			break;
				
			default:
			break;
		}
	}		
}

void PORTB_IRQHandler(void)
{
	PORTB->PCR[2] = PORT_PCR_MUX(1) | PORT_PCR_PE_MASK | PORT_PCR_PS_MASK | PORT_PCR_ISF_MASK; // disable interrupt at BP.13
	SCB->SCR = 0;						// disable deep sleep mode
}	
	
