#include <MKL05Z4.h>
#include "radio.h"
#include "hardware.h"

extern uint8_t SPIbuf[];

const uint8_t Radio_PowerUp[] = {0x02, 0x01, 0x00, 0x01, 0xC9, 0xC3, 0x80};

const uint8_t TX_FIFO_1[] = {
0x66, 0x9B, 0x51, 0x7D, 0x56, 0x02, 0xC2, 0x8F, 0xA2, 0x1C, 0x8F, 0x41, 0xC3, 0x7D, 0xF7, 0xA7, 0xF4, 0x28, 0xC7, 0x4F, \
0xDF, 0x5D, 0xC2, 0x2C, 0x01, 0x20, 0x48, 0x5C, 0xD4, 0xC2, 0x5E, 0x68, 0x92, 0xE6, 0x3C, 0x21, 0xED, 0x0B, 0x75, 0x57, \
0x44, 0xB5, 0x53, 0x7C, 0xCB, 0x89, 0x5F, 0x10, 0x04, 0xB9, 0x83, 0x65, 0x9C, 0x95, 0x70, 0x64, 0xA9, 0xE8, 0x38, 0x42, \
0x50, 0x94, 0xD3, 0xA1, 0x27, 0x22, 0x65, 0x53, 0xE1, 0xF1, 0x60, 0x62, 0xAA, 0x3A, 0x6F, 0x9B, 0xDC, 0x9E, 0x5E, 0xAC, \
0x88, 0xD5, 0xC0, 0x51, 0xCE, 0xC3, 0x67, 0xE7, 0xAA, 0x28, 0x20, 0xD4, 0xC5, 0x0C, 0xD7, 0x7C, 0x41, 0x05, 0xBC, 0xC2, \
0x12, 0x7A, 0x7D, 0x53, 0x2A, 0xCB, 0xAF, 0x08, 0x7A, 0x18, 0xE0, 0xAC, 0x6B, 0xE1};

const uint8_t TX_FIFO_2[] = {
 0x66, 0x20, 0xD8, 0x95, 0x26, 0x1E, 0xD9, 0x37, 0xFA, 0xCB, 0xA1, 0x3E, 0xC4, 0x16, 0xC5, 0x35, 0xEB, 0xDE, 0x1F, 0x41, \
0x3F, 0xE5, 0xFC, 0x1F, 0x97, 0x02, 0x37, 0x30, 0xC3, 0x39, 0x20, 0xBB, 0x8F, 0xA2, 0xD7, 0xDE, 0x57, 0x79, 0xCF, 0x0D, \
0x8B, 0xD5, 0xEE, 0x3C, 0x1E, 0xC7, 0xF7, 0x09, 0xC3, 0x81, 0x0B, 0x38, 0x57, 0xFB, 0xC5, 0x14, 0x1B, 0x25, 0xAF, 0x99, \
0x4A, 0xE8, 0xE1, 0x90, 0xD1, 0x8B, 0xF1, 0xBC, 0x5C, 0x4D, 0x4B, 0xB2, 0xE1, 0xED, 0x05, 0xD6, 0x11, 0x96, 0x36, 0x65, \
0x1E, 0x1E, 0x24, 0x33, 0x8C, 0x80, 0x03, 0xA5, 0x2A, 0x2A, 0x2B, 0xB1, 0x89, 0xC8, 0x61, 0x5E, 0x1C, 0x88, 0x1F, 0xD2, \
0x53, 0x05, 0x2A, 0x59, 0xDF, 0x1F, 0xA2, 0x64, 0x67, 0x87, 0x0E, 0x83};

const uint8_t Radio_EZconfigCheck[] = {0x19, 0xA3, 0x7F};

const uint8_t Radio_Config[] = {0x07,					// config length
	0x08, 0x13, 0x01, 0x01, 0x01, 0x01, 0x27, 0x0B, 0x00,		// configure GPIO
 	0x06, 0x11, 0x01, 0x02, 0x00, 0x01,	0x10,				// enable PH interrupts
	0x08, 0x11, 0x02, 0x04, 0x00, 0x08, 0x06, 0x04, 0x0A,		// FRR config
	0x09, 0x11, 0x11, 0x04, 0x00, 0x03, 0xCB, 0x89, 0xCB, 0x89, // sync word config
	0x05, 0x11, 0x22, 0x01, 0x01, 0x4F,					// PA level	
	0x05, 0x11, 0x24, 0x01, 0x03, 0x52,					// XCO tuning bank
	0x08, 0x32, 0x00, 0x00, 0x00, 0x04, 0x00, 0x00, 0x00};	// put radio in RX mode

const uint8_t Radio_ClearFIFO[] = {0x15, 0x03};				// clear RX&TX FIFOs
const uint8_t Radio_RX_mode[] = {0x32, 0x00, 0x00, 0x00, 0x04, 0x00, 0x00, 0x00};

void Radio_setup()
{	
	uint8_t colNumber;
	uint8_t i;
	uint32_t d;
	const uint8_t* configPtr = Radio_Config;	// pointer to radio configuration
	uint8_t rowNumber = *configPtr;
	configPtr++;

	for (d=0; d<100000; d++){}			// power-up delay	
	SPIWriteBuf(Radio_PowerUp, 7, 0);		// power-up sequence
	SPIWriteBuf(TX_FIFO_1, 114, 0);
	SPIWriteBuf(TX_FIFO_2, 112, 0);
	SPIWriteBuf2(Radio_EZconfigCheck, 3, 1);
		
	for (i=0; i<rowNumber; i++)			// set other radio properties
	{
		colNumber = *configPtr;			// # of bytes to send to radio
		configPtr++;				// pointer to the row array
		SPIWriteBuf(configPtr, colNumber, 0); // send row array to radio	
		configPtr += colNumber;			// move pointer to the next row
	}	
}	
	
void Read_radio()
{
	const uint8_t b[] = {0x77};
	SPIbuf[0] = 0;					// clear buffer
	SPIbuf[1] = 0;
	SPIbuf[2] = 0;
	SPIbuf[3] = 0;
	SPIWriteBuf(b, 1, 4);				// fills out 4 bytes in SPIbuf
}

void Clear_radioIF()
{
	const uint8_t b[] = {0x20};
	SPIWriteBuf(Radio_ClearFIFO, 2, 0);
	SPIWriteBuf(b, 1, 0);				// clear radio interrupt flags
	SPIWriteBuf(Radio_RX_mode, 8, 0);
}	
