#include "hardware.h"
#include <MKL03Z4.h> 
#include <core_cm0plus.h>

void MCG_setup(void)							// configure system clock
{
	SIM->CLKDIV1 = SIM_CLKDIV1_OUTDIV4(3);			// set 1:4 bus clock divider
}

void SMC_setup(void)							// configure low-power run/stop modes
{
	SMC->PMPROT = SMC_PMPROT_AVLP_MASK;				// allow VLPR, VLPW, VLPS modes
	SMC->PMCTRL = SMC_PMCTRL_RUNM(2) | SMC_PMCTRL_STOPM(2); // enter VLPS mode in STOP 
}

void PORTS_setup(void)							// configure I/O ports
{
	SIM->SCGC5 |= SIM_SCGC5_PORTA_MASK | SIM_SCGC5_PORTB_MASK;	   // enable clock for I/O ports
	PORTA->GPCLR = PORT_GPCLR_GPWE(0x20) | PORT_GPCLR_GPWD(0x100); // configure PORTA[3:5] for GPIO
	PORTA->GPCLR = PORT_GPCLR_GPWE(0x18) | PORT_GPCLR_GPWD(0x103); // pull-up on those pins
	PORTB->GPCLR = PORT_GPCLR_GPWE(0x3E) | PORT_GPCLR_GPWD(0x103); // configure PORTB[1:5] for GPIO
	PTA->PDDR = 0x20;							// configure CS pin for output
	PTA->PDOR = 0x20;							// put CS high
	PTB->PDDR = 0x00;							// configure PB1 - PB5 for intput
}

void LPTMR0_setup(void)							// Low-Power Timer configuration
{												
	SIM->SCGC5 |= SIM_SCGC5_LPTMR_MASK;				// enable clock for LPTMR
	LPTMR0->CMR = 30;							// timer delay for debouncing (in ms)
	LPTMR0->PSR = LPTMR_PSR_PBYP_MASK | LPTMR_PSR_PCS(1); // set LPO as clock source, no prescaler
	NVIC_ClearPendingIRQ(LPTMR0_IRQn);				// clear pending LPTRM0 interrupt
	NVIC_EnableIRQ(LPTMR0_IRQn);					// enable LPTMR0 interrupt in NVIC
	LPTMR0->CSR = LPTMR_CSR_TEN_MASK | LPTMR_CSR_TCF_MASK | LPTMR_CSR_TIE_MASK; // start timer
}	

void SPI0_setup(void)
{
	PORTA->GPCLR = PORT_GPCLR_GPWE(0xC0) | PORT_GPCLR_GPWD(0x300); // configure PORTA[6:7] for SPI0
	PORTB->GPCLR = PORT_GPCLR_GPWE(0x01) | PORT_GPCLR_GPWD(0x300); // configure PORTB[0] for SPI0
	SIM->SCGC4 |= SIM_SCGC4_SPI0_MASK;				// enable clock for SPI0 module
	SPI0->BR = 0;							// set bus_freq/2 baud rate	
	NVIC_ClearPendingIRQ(SPI0_IRQn);				// enable SPI0 interrupt in NVIC
	NVIC_EnableIRQ(SPI0_IRQn);
}
