#include <MKL03Z4.h>
#include "hardware.h"
#include "radio.h"
#define ON_THRESHOLD  0x3F					// debouncing constants
#define OFF_THRESHOLD 0xFC
#define FORWARD 	1						// radio commands
#define LEFT 	2
#define BACKWARDS 3
#define RIGHT 	4 
#define STOP	5

uint8_t shiftRegL;						// shift register for left button
uint8_t shiftRegR;						// shift register for right button
uint8_t shiftRegF;						// shift register for forward button
uint8_t shiftRegB;						// shift register for backwards button
uint8_t shiftRegC;						// shift register for central button
uint8_t butState;							//... and button state for debouncing (LRFBC)
uint8_t packet[] = {0x66, 3, 0xAA, 0xBB, 0x00};		// packet to send; 0x66=command, 3=length, AA=TX_ID, BB=RX_ID
	
int main(void)
{  
	MCG_setup();						// configure clock for VLPR mode
	SMC_setup();						// configure low-power modes
	PORTS_setup();						// I/O ports setup	
	SPI0_setup();						// configure SPI0 module
	Radio_setup();
	LPTMR0_setup();
	
	shiftRegL = shiftRegR = 0xFF;				// init RAM variables (declaring these variables as hexadecimals)
	shiftRegF = shiftRegB = 0xFF;				// init RAM variables (declaring these variables as hexadecimals)
	shiftRegC = butState = 0xFF;				// init RAM variables (declaring these variables as hexadecimals)
	
	while(1)							// main application loop
	{	
		__WFI();						// wait for wake-up event
		if (packet[4])
		{	
			Radio_send(packet, 5);			// compose packet and send
			packet[4] = 0;
		}	
	}	
}

void LPTMR0_IRQHandler(void)
{
	packet[4] = 0;
	shiftRegL = (shiftRegL >> 1) | ((PTB->PDIR & L_BUTTON) << 4); // update shift register
	if (butState & 0x01)					// old button state = OFF
	{
		if (shiftRegL <= ON_THRESHOLD)		// button is pressed
		{
			butState &= ~(0x01);	
			packet[4] = LEFT;
		}
	}
	else if (shiftRegL >= OFF_THRESHOLD)		// button is released
		butState |= 0x01;
	
	shiftRegR = (shiftRegR >> 1) | ((PTA->PDIR & R_BUTTON) << 3); // update shift register
	if (butState & 0x02)					// old button state = OFF
	{
		if (shiftRegR <= ON_THRESHOLD)		// button is pressed
		{
			butState &= ~(0x02);	
			packet[4] = RIGHT;
		}
	}
	else if (shiftRegR >= OFF_THRESHOLD)		// button is released
		butState |= 0x02;
	
	shiftRegF = (shiftRegF >> 1) | ((PTB->PDIR & F_BUTTON) << 3); // update shift register
	if (butState & 0x04)					// old button state = OFF
	{
		if (shiftRegF <= ON_THRESHOLD)		// button is pressed
		{
			butState &= ~(0x04);	
			packet[4] = FORWARD;
		}
	}
	else if (shiftRegF >= OFF_THRESHOLD)		// button is released
		butState |= 0x04;
	
	shiftRegB = (shiftRegB >> 1) | ((PTB->PDIR & B_BUTTON) << 2); // update shift register
	if (butState & 0x08)					// old button state = OFF
	{
		if (shiftRegB <= ON_THRESHOLD)		// button is pressed
		{
			butState &= ~(0x08);	
			packet[4] = BACKWARDS;
		}
	}
	else if (shiftRegB >= OFF_THRESHOLD)		// button is released
		butState |= 0x08;
	
	shiftRegC = (shiftRegC >> 1) | ((PTA->PDIR & C_BUTTON) << 4); // update shift register
	if (butState & 0x10)					// old button state = OFF
	{
		if (shiftRegC <= ON_THRESHOLD)		// button is pressed
		{
			butState &= ~(0x10);
			packet[4] = STOP;		
		}
	}
	else if (shiftRegC >= OFF_THRESHOLD)		// button is released
		butState |= 0x10;
	
	LPTMR0->CSR |= LPTMR_CSR_TCF_MASK;			// clear interrupt flag	
}	
	
