// RF paramaters: freq=915mHz, channel=0, modulation=2FSK, data rate=2.4kbps, deviation=30kHz 
// preamble=4 bytes, sync word=0xD3 0x91 0xD3 0x91, CRC=2bytes
// by using CC1101 as receiver, set its RX filter BW = 80 kHz

#include <MKL03Z4.h>
#include "radio.h"
#include "hardware.h"
extern uint8_t packet[];
extern uint8_t SPIbuf[];

uint8_t Radio_PowerUp[] = {0x02, 0x01, 0x00, 0x01, 0xC9, 0xC3, 0x80};

uint8_t TX_FIFO_1[] = {
0x66, 0x98, 0x5B, 0x41, 0xE2, 0x32, 0xD0, 0x49, 0x5A, 0x94, 0xAC, 0xBE, 0x0B, 0xC9, 0xFC, 0x20, 0xDC, 0xCA, 0x71, 0xBB, \
0x56, 0x55, 0xCB, 0x20, 0x15, 0x70, 0xD0, 0xEA, 0x3F, 0x0C, 0x8C, 0x23, 0xC7, 0xA1, 0x59, 0xE4, 0x24, 0x20, 0x30, 0x36, \
0x90, 0x02, 0x10, 0x4B, 0xF5, 0xB0, 0x4D, 0xE0, 0x4A, 0x32, 0x1B, 0x59, 0x17, 0xCE, 0x7F, 0xEB, 0xD5, 0xBA, 0x7D, 0xB5, \
0xF0, 0x65, 0x30, 0xC1, 0x24, 0x61, 0xEA, 0xF7, 0x1E, 0x2B, 0xB2, 0x51, 0xEF, 0x2B, 0x99, 0x06, 0xAA, 0xEB, 0x70, 0x7F, \
0x83, 0x03, 0x0B, 0x10, 0xFB, 0xF8, 0x4C, 0x9D, 0x45, 0x33, 0x18, 0x18, 0xFE, 0x31, 0xC5, 0x97, 0x54, 0x04, 0xC2, 0xC9, \
0x29, 0xD6, 0x06, 0xA8, 0x2F, 0xCF, 0xAF, 0x13, 0x23, 0x9D, 0x27, 0x26, 0xCA, 0x1D};

uint8_t TX_FIFO_2[] = {
0x66, 0xE7, 0x47, 0x4F, 0xB4, 0xAB, 0x0D, 0x78, 0xA5, 0xAB, 0x29, 0x4E, 0xD8, 0x71, 0xC9, 0x73, 0xF2, 0xBA, 0x9E, 0x15, \
0xC7, 0x02, 0xB4, 0xF7, 0x5D, 0xC4, 0x1F, 0x54, 0x67, 0xBC, 0xEA, 0x10, 0xCC, 0xDE, 0x50, 0xC4, 0x1F, 0x9C, 0x24, 0x29, \
0x23, 0xF1, 0xCF, 0x2B, 0xA3, 0x32, 0x44, 0x92, 0x3F, 0xDA, 0xDC, 0x10, 0x55, 0x23, 0x1A, 0xF9, 0xBD, 0x95, 0xDD, 0x16, \
0x4B, 0xCA, 0x28, 0xE9, 0x74, 0x43, 0x99, 0x79, 0xB8, 0x8B, 0x87, 0x8E, 0xC1, 0xA9, 0x5E, 0x91, 0x53, 0x82, 0xC2, 0x23, \
0xBD, 0x4A, 0x10, 0x7C, 0x90, 0x65, 0x13, 0x9E, 0xDC, 0x8D, 0xC2, 0x19, 0x00, 0x08, 0xDE, 0x59, 0x80, 0xD1, 0x88, 0x73, \
0xE1, 0x66, 0xCF, 0x48, 0xE7, 0xEF, 0x11, 0xE1, 0xDF, 0x00, 0x8F, 0x9E};

uint8_t Radio_EZconfigCheck[] = {0x19, 0x3E, 0x3E};

uint8_t Radio_Config[] = {0x07,						// config length
	0x08, 0x13, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0B, 0x00,		// configure GPIO
 	0x05, 0x11, 0x01, 0x01, 0x00, 0x00,					// disable interrupts
	0x08, 0x11, 0x02, 0x04, 0x00, 0x08, 0x06, 0x04, 0x0A,		// FRR config
	0x09, 0x11, 0x11, 0x04, 0x00, 0x03, 0xCB, 0x89, 0xCB, 0x89, // sync word config
	0x05, 0x11, 0x22, 0x01, 0x01, 0x4F,					// PA level	
	0x05, 0x11, 0x24, 0x01, 0x03, 0x52,					// XCO tuning bank
	0x02, 0x34, 0x01};							// put radio on sleep

uint8_t Radio_ClearFIFO[] = {0x15, 0x03};					// clear RX&TX FIFOs
uint8_t Radio_TX[] = {0x31, 0x00, 0x10, 0x00, 0x04, 0x00};		// start TX of 4 bytes, sleep afterwards
	
void Radio_setup()
{	
	uint8_t colNumber;
	uint8_t i;
	uint32_t d;
	uint8_t* configPtr = Radio_Config;		// pointer to radio configuration
	uint8_t rowNumber = *configPtr;
	configPtr++;

	for (d=0; d<100000; d++){}			// power-up delay
	SPIWriteBuf(Radio_PowerUp, 7, 0);		// power-up sequence
	SPIWriteBuf(TX_FIFO_1, 114, 0);
	SPIWriteBuf(TX_FIFO_2, 112, 0);
	SPIWriteBuf(Radio_EZconfigCheck, 3, 2);
	
	for (i=0; i<rowNumber; i++)			// set other radio properties
	{
		colNumber = *configPtr;			// # of bytes to send to radio
		configPtr++;				// pointer to the row array
		SPIWriteBuf(configPtr, colNumber, 0); // send row array to radio	
		configPtr += colNumber;			// move pointer to the next row
	}	
}	
	
void Radio_send(uint8_t pac[], uint8_t len)	// transmit packet
{
	SPIWriteBuf(Radio_ClearFIFO, 2, 0);		// clear RX&TX FIFOs	
	SPIWriteBuf(pac, len, 0); 			// load packet to TX_FIFO
	SPIWriteBuf(Radio_TX, 6, 0);			// start transmission
}
